@@ -4,18 +4,18 @@ import re
 
 from .common import InfoExtractor
 from ..compat import (
-    compat_urlparse,
     compat_parse_qs,
+    compat_urlparse,
 )
 from ..utils import (
-    clean_html,
     ExtractorError,
+    clean_html,
     format_field,
     int_or_none,
-    unsmuggle_url,
+    remove_start,
     smuggle_url,
     traverse_obj,
-    remove_start
+    unsmuggle_url,
 )
 
 
@@ -518,8 +518,6 @@ class KalturaIE(InfoExtractor):
             formats.extend(fmts)
             self._merge_subtitles(subs, target=subtitles)
 
-        self._sort_formats(formats)
-
         if captions:
             for caption in captions.get('objects', []):
                 # Continue if caption is not ready
