@@ -1,7 +1,7 @@
 import math
 
 from .common import InfoExtractor
-from ..utils import traverse_obj, try_call, InAdvancePagedList
+from ..utils import InAdvancePagedList, str_or_none, traverse_obj, try_call
 
 
 class XimalayaBaseIE(InfoExtractor):
@@ -19,7 +19,7 @@ class XimalayaIE(XimalayaBaseIE):
                 'id': '47740352',
                 'ext': 'm4a',
                 'uploader': '小彬彬爱听书',
-                'uploader_id': 61425525,
+                'uploader_id': '61425525',
                 'uploader_url': 'http://www.ximalaya.com/zhubo/61425525/',
                 'title': '261.唐诗三百首.卷八.送孟浩然之广陵.李白',
                 'description': "contains:《送孟浩然之广陵》\n作者：李白\n故人西辞黄鹤楼，烟花三月下扬州。\n孤帆远影碧空尽，惟见长江天际流。",
@@ -48,7 +48,7 @@ class XimalayaIE(XimalayaBaseIE):
                 'id': '47740352',
                 'ext': 'm4a',
                 'uploader': '小彬彬爱听书',
-                'uploader_id': 61425525,
+                'uploader_id': '61425525',
                 'uploader_url': 'http://www.ximalaya.com/zhubo/61425525/',
                 'title': '261.唐诗三百首.卷八.送孟浩然之广陵.李白',
                 'description': "contains:《送孟浩然之广陵》\n作者：李白\n故人西辞黄鹤楼，烟花三月下扬州。\n孤帆远影碧空尽，惟见长江天际流。",
@@ -107,7 +107,7 @@ class XimalayaIE(XimalayaBaseIE):
         return {
             'id': audio_id,
             'uploader': audio_info.get('nickname'),
-            'uploader_id': audio_uploader_id,
+            'uploader_id': str_or_none(audio_uploader_id),
             'uploader_url': f'{scheme}://www.ximalaya.com/zhubo/{audio_uploader_id}/' if audio_uploader_id else None,
             'title': audio_info['title'],
             'thumbnails': thumbnails,
